@@ -97,7 +97,7 @@ describe 'heat::api_cfn' do
 
     context 'with $sync_db set to false in ::heat' do
       let :pre_condition do
-        "class { '::heat::keystone::authtoken':
+        "class { 'heat::keystone::authtoken':
            password => 'a_big_secret',
          }
          class {'heat':
