@@ -42,15 +42,7 @@ describe 'heat::client' do
         when 'Debian'
           { :client_package_name => 'python3-heatclient' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :client_package_name => 'python3-heatclient' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :client_package_name => 'python3-heatclient' }
-            else
-              { :client_package_name => 'python-heatclient' }
-            end
-          end
+          { :client_package_name => 'python3-heatclient' }
         end
       end
 
